window.Gleam.initSearch([{"doc":"js_parser","title":"js_parser","content":"# js_parser\n\n[![Package Version](https://img.shields.io/hexpm/v/js_parser)](https://hex.pm/packages/js_parser) [![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/js_parser/)\n\nA lexer and parser for JavaScript, written in Gleam.\n\nThis project is inspired by the [`js-tokens`](https://github.com/lydell/js-tokens)\nand [glexer](https://github.com/DanielleMaywood/glexer) packages, and aims to provide\na tool to build ECMA-262 syntax trees for gleam projects.\n\n## Installation\n\n```sh\ngleam add js_parser\n```\n\n## Usage\n\n`someFile.js`\n\n```javascript\nexport function someFunction() {\n    let someVar;\n}\n```\n\nThe lexer can take any string and returns a list of tokens, including whitespace\ncharacters.\n\n```gleam\nimport js_parser\n\npub fn main() {\n  let contents = js_parser.read_file(&quot;path/to/someFile.js&quot;)\n  |&gt; js_parser.parse\n  |&gt; io.debug\n}\n```\n\nShould output:\n\n```plaintext\n[\n  KeywordExport, CharWhitespace(&quot; &quot;), KeywordFunction, CharWhitespace(&quot; &quot;), IdentifierName(&quot;someFunction&quot;),CharOpenParen, CharCloseParen, CharWhitespace(&quot; &quot;), CharOpenBrace,\n  LineTerminatorSequence(&quot;\\n&quot;), CharWhitespace(&quot;    &quot;),\n  IdentifierName(&quot;let&quot;), CharWhitespace(&quot; &quot;), IdentifierName(&quot;someVar&quot;), CharSemicolon,LineTerminatorSequence(&quot;\\n&quot;),\n  CharCloseBrace, LineTerminatorSequence(&quot;\\n&quot;)\n]\n```\n\n```sh\ngleam run -- --f samples/js/index.js\ngleam test\n```\n","url":"index.html"},{"doc":"js_parser/predicates","title":"is_digit","content":"pub fn is_digit(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_digit\njs_parser/predicates is_digit","url":"js_parser/predicates.html#is_digit"},{"doc":"js_parser/predicates","title":"is_end_of_input","content":"pub fn is_end_of_input(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_end_of_input\njs_parser/predicates is_end_of_input","url":"js_parser/predicates.html#is_end_of_input"},{"doc":"js_parser/predicates","title":"is_end_of_segment","content":"pub fn is_end_of_segment(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_end_of_segment\njs_parser/predicates is_end_of_segment","url":"js_parser/predicates.html#is_end_of_segment"},{"doc":"js_parser/predicates","title":"is_identifier_char","content":"pub fn is_identifier_char(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_identifier_char\njs_parser/predicates is_identifier_char","url":"js_parser/predicates.html#is_identifier_char"},{"doc":"js_parser/predicates","title":"is_letter","content":"pub fn is_letter(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_letter\njs_parser/predicates is_letter","url":"js_parser/predicates.html#is_letter"},{"doc":"js_parser/predicates","title":"is_punctuator_start","content":"pub fn is_punctuator_start(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_punctuator_start\njs_parser/predicates is_punctuator_start","url":"js_parser/predicates.html#is_punctuator_start"},{"doc":"js_parser/predicates","title":"js_parser/predicates","content":"","url":"js_parser/predicates.html"},{"doc":"js_parser","title":"Token","content":"pub type Token {\n  StringLiteral(value: String, closed: Bool)\n  TemplateLiteral(components: List(Token))\n  EmptyTemplateLiteral\n  NoSubstitutionTemplate(value: String, closed: Bool)\n  TemplateHead(value: String)\n  TemplateMiddle(value: String)\n  TemplateTail(value: String, closed: Bool)\n  RegularExpressionLiteral(value: String, closed: Bool)\n  SingleLineComment(value: String)\n  MultiLineComment(value: String, closed: Bool)\n  HashbangComment(value: String)\n  IdentifierName(value: String)\n  PrivateIdentifier(value: String)\n  NumericLiteral(value: String)\n  WhiteSpace(value: String)\n  LineTerminatorSequence(value: String)\n  Invalid\n  EOF\n  KeywordAwait\n  KeywordBreak\n  KeywordCase\n  KeywordCatch\n  KeywordClass\n  KeywordConst\n  KeywordContinue\n  KeywordDebugger\n  KeywordDefault\n  KeywordDelete\n  KeywordDo\n  KeywordElse\n  KeywordEnum\n  KeywordExport\n  KeywordExtends\n  KeywordFalse\n  KeywordFinally\n  KeywordFor\n  KeywordFunction\n  KeywordIf\n  KeywordImport\n  KeywordIn\n  KeywordInstanceof\n  KeywordNew\n  KeywordNull\n  KeywordReturn\n  KeywordSuper\n  KeywordSwitch\n  KeywordThis\n  KeywordThrow\n  KeywordTrue\n  KeywordTry\n  KeywordTypeof\n  KeywordVar\n  KeywordVoid\n  KeywordWhile\n  KeywordWith\n  KeywordYield\n  CharSemicolon\n  CharColon\n  CharComma\n  CharOpenBracket\n  CharCloseBracket\n  CharOpenBrace\n  CharCloseBrace\n  CharOpenParen\n  CharCloseParen\n  CharWhitespace(value: String)\n  CharDot\n  Punctuator(Token)\n  CharAsterisk\n  CharMinus\n  CharPlus\n  CharEquals\n  CharMod\n  CharBackslash\n  PlusAssign\n  MinusAssign\n  StarAssign\n  DivAssign\n  ModAssign\n  ExpAssign\n  AndAssign\n  OrAssign\n  XorAssign\n  ShlAssign\n  ShrAssign\n  UshrAssign\n  OperatorExp\n  OperatorIncrement\n  OperatorDecrement\n  OperatorAND\n  OperatorOR\n  OperatorXOR\n  OperatorSHL\n  OperatorSHR\n  OperatorUSHR\n  OperatorNOT\n  OperatorLogicalAND\n  OperatorLogicalOR\n  OperatorLogicalNOT\n  OperatorNULLISH\n  ComparisonEQL\n  ComparisonNotEQL\n  ComparisonStrictEQL\n  ComparisonStrictNotEQL\n  LT\n  GT\n  LTE\n  GTE\n  Arrow\n  CharQuestion\n  OperatorOptional\n}\n\nStringLiteral(value: String, closed: Bool)\n\n\nTemplateLiteral(components: List(Token))\n\n\nEmptyTemplateLiteral\n\n\nNoSubstitutionTemplate(value: String, closed: Bool)\n\n\nTemplateHead(value: String)\n\n\nTemplateMiddle(value: String)\n\n\nTemplateTail(value: String, closed: Bool)\n\n\nRegularExpressionLiteral(value: String, closed: Bool)\n\n\nSingleLineComment(value: String)\n\n\nMultiLineComment(value: String, closed: Bool)\n\n\nHashbangComment(value: String)\n\n\nIdentifierName(value: String)\n\n\nPrivateIdentifier(value: String)\n\n\nNumericLiteral(value: String)\n\n\nWhiteSpace(value: String)\n\n\nLineTerminatorSequence(value: String)\n\n\nInvalid\n\n\nEOF\n\n\nKeywordAwait\n\n\nKeywordBreak\n\n\nKeywordCase\n\n\nKeywordCatch\n\n\nKeywordClass\n\n\nKeywordConst\n\n\nKeywordContinue\n\n\nKeywordDebugger\n\n\nKeywordDefault\n\n\nKeywordDelete\n\n\nKeywordDo\n\n\nKeywordElse\n\n\nKeywordEnum\n\n\nKeywordExport\n\n\nKeywordExtends\n\n\nKeywordFalse\n\n\nKeywordFinally\n\n\nKeywordFor\n\n\nKeywordFunction\n\n\nKeywordIf\n\n\nKeywordImport\n\n\nKeywordIn\n\n\nKeywordInstanceof\n\n\nKeywordNew\n\n\nKeywordNull\n\n\nKeywordReturn\n\n\nKeywordSuper\n\n\nKeywordSwitch\n\n\nKeywordThis\n\n\nKeywordThrow\n\n\nKeywordTrue\n\n\nKeywordTry\n\n\nKeywordTypeof\n\n\nKeywordVar\n\n\nKeywordVoid\n\n\nKeywordWhile\n\n\nKeywordWith\n\n\nKeywordYield\n\n\nCharSemicolon\n\n\nCharColon\n\n\nCharComma\n\n\nCharOpenBracket\n\n\nCharCloseBracket\n\n\nCharOpenBrace\n\n\nCharCloseBrace\n\n\nCharOpenParen\n\n\nCharCloseParen\n\n\nCharWhitespace(value: String)\n\n\nCharDot\n\n\nPunctuator(Token)\n\n\nCharAsterisk\n\n\nCharMinus\n\n\nCharPlus\n\n\nCharEquals\n\n\nCharMod\n\n\nCharBackslash\n\n\nPlusAssign\n\n\nMinusAssign\n\n\nStarAssign\n\n\nDivAssign\n\n\nModAssign\n\n\nExpAssign\n\n\nAndAssign\n\n\nOrAssign\n\n\nXorAssign\n\n\nShlAssign\n\n\nShrAssign\n\n\nUshrAssign\n\n\nOperatorExp\n\n\nOperatorIncrement\n\n\nOperatorDecrement\n\n\nOperatorAND\n\n\nOperatorOR\n\n\nOperatorXOR\n\n\nOperatorSHL\n\n\nOperatorSHR\n\n\nOperatorUSHR\n\n\nOperatorNOT\n\n\nOperatorLogicalAND\n\n\nOperatorLogicalOR\n\n\nOperatorLogicalNOT\n\n\nOperatorNULLISH\n\n\nComparisonEQL\n\n\nComparisonNotEQL\n\n\nComparisonStrictEQL\n\n\nComparisonStrictNotEQL\n\n\nLT\n\n\nGT\n\n\nLTE\n\n\nGTE\n\n\nArrow\n\n\nCharQuestion\n\n\nOperatorOptional\n\n\nSynonyms:\njs_parser.Token\njs_parser Token","url":"js_parser.html#Token"},{"doc":"js_parser","title":"parse","content":"pub fn parse(input: String) -&gt; List(Token)\n\nSynonyms:\njs_parser.parse\njs_parser parse","url":"js_parser.html#parse"},{"doc":"js_parser","title":"js_parser","content":"","url":"js_parser.html"}]);